/*---------------------------------------------------------------------------------
    FILENAME:       RAM.ld

    DESCRIPTION:    Linker directive file for running program from RAM.

    DATE:           2 October 2007
---------------------------------------------------------------------------------*/

/* split 64k bytes of RAM into two parts: half for code and half for data */
MEMORY
{
    SRAM (rw) : ORIGIN = 0x00202000, LENGTH = 57344
}

SECTIONS
{

  /* first section .text used for code */

  .text :
  {
    *startup.o (.text)         /* startup code */
    *(.text)                   /* remaining code */

    *(.glue_7t) *(.glue_7)

  } >SRAM =0

  . = ALIGN(4);

  /* .rodata for read-only data (constants) */

  .rodata :
  {
    *(.rodata)
  } >SRAM

  . = ALIGN(4);

  _etext = . ;
  PROVIDE (etext = .);

  /* .data section for initialized data */

  .data : AT (_etext)
  {
    _data = . ;
    *(.data)
    SORT(CONSTRUCTORS)
  } >SRAM
  . = ALIGN(4);

  _edata = . ;
   PROVIDE (edata = .);

  /* .bss section for uninitialized data */

  .bss :
  {
    __bss_start = . ;
    __bss_start__ = . ;
    *(.bss)
    *(COMMON)
  } >SRAM
  . = ALIGN(4);
  __bss_end__ = . ;
  __bss_end__ = . ;

  _end = .;
  PROVIDE (end = .);

}
